import { Construct } from "constructs";
import { Duration } from "aws-cdk-lib";
import { Queue } from "aws-cdk-lib/aws-sqs";
import * as kms from 'aws-cdk-lib/aws-kms';
import { IAlarmAction } from "aws-cdk-lib/aws-cloudwatch";
import { ITopic } from 'aws-cdk-lib/aws-sns';
import * as iam from "aws-cdk-lib/aws-iam";
import { MonitoringFacade, IDashboardFactory } from "cdk-monitoring-constructs";
/**
 * Alarm properties for StandardQueue
 */
export interface StandardQueueAlarmProps {
    /**
     * Minimum number of messages visible.
     */
    readonly minSize?: number;
    /**
     * Maximum number of messages visible.
     */
    readonly maxSize?: number;
    /**
     * Maximum approximate age of the oldest message in the queue.
     *
     * @default Duration.minutes(15) for critical alarm
     */
    readonly maxAge?: Duration;
    /**
     * Maximum time to drain the queue.
     */
    readonly maxTimeToDrain?: Duration;
    /**
     * Minimum number of incoming messages.
     */
    readonly minIncoming?: number;
    /**
     * Maximum number of incoming messages.
     */
    readonly maxIncoming?: number;
    /**
     * Maximum number of visible messages in the dead-letter queue
     *
     * @default 0 for critical alarm
     */
    readonly deadLetterQueueMaxSize?: number;
    /**
     * Maximum age of the oldest messages in the dead-letter queue
     */
    readonly deadLetterQueueMaxAge?: Duration;
    /**
     * Maximum number of incoming messages in the dead-letter queue
     */
    readonly deadLetterQueueMaxIncoming?: number;
    /**
     * Topics to send alarm notifications
     */
    readonly notifyTopics?: [ITopic];
    /**
     * Actions to send alarm notifications
     */
    readonly notifyActions?: [IAlarmAction];
}
/**
 * Properties for a StandardQueue
 */
export interface StandardQueueProps {
    /**
     * The number of seconds Amazon SQS retains a message. Value must be between
     * 60 and 1209600 seconds (14 days).
     *
     * @default Duration.seconds(1209600)
     *
     */
    readonly retentionPeriod?: Duration;
    /**
     * The number of seconds a consumer has to handle the message and delete it
     * from the queue before it becomes visible again for another consumer. Value
     * must be between 0 and 43200 seconds (12 hours).
     *
     * @default Duration.seconds(30)
     */
    readonly visibilityTimeout?: Duration;
    /**
     * The KMS key to use for encryption. If not set, the AWS master key for SQS
     * will be used.
     */
    readonly encryptionMasterKey?: kms.IKey;
    /**
     * The length of time that Amazon SQS reuses a data key before calling KMS again.
     * This value affects pricing as you are charged for KMS usage. Value must be
     * between 60 and 86,400 seconds (24 hours).
     *
     * @default Duration.minutes(15)
     */
    readonly dataKeyReuse?: Duration;
    /**
     * The maximum number of times a message can be unsuccessful before being moved
     * to the dead-letter queue. Set this value to -1 to disable the dead-letter queue.
     *
     * @default 3
     */
    readonly maxReceiveCount?: number;
    /**
     * The DashboardFactory to use when generating CloudWatch dashboards.
     *
     * If not defined, dashboards are not generated.
     */
    readonly dashboardFactory?: IDashboardFactory;
    /**
     * Alarm thresholds for critical alarms.
     *
     * If no properties are provided, a set of default alarms are created.
     */
    readonly criticalAlarmProps?: StandardQueueAlarmProps;
    /**
     * Alarm threshold for warning alarms.
     *
     * If no properties are provided, a set of default alarms are created.
     */
    readonly warningAlarmProps?: StandardQueueAlarmProps;
}
export declare class StandardQueue extends Construct {
    static readonly DEFAULT_MAX_RECEIVE_COUNT = 3;
    static readonly DEFAULT_RETENTION_PERIOD: Duration;
    readonly monitoring: MonitoringFacade;
    readonly queue: Queue;
    readonly deadLetterQueue: Queue;
    constructor(scope: Construct, id: string, props?: StandardQueueProps);
    grantConsumeMessages(grantee: iam.IGrantable): iam.Grant;
    grantSendMessages(grantee: iam.IGrantable): iam.Grant;
    grantPurge(grantee: iam.IGrantable): iam.Grant;
    grant(grantee: iam.IGrantable, ...actions: string[]): iam.Grant;
}
